pub struct CharacterClass {
pub character_id: CharacterId,
pub class_id: ClassId,
pub level: u64,
pub xp: u64,
}Fields
character_id: CharacterIdclass_id: ClassIdlevel: u64xp: u64Trait Implementations
Sourceimpl Clone for CharacterClass
impl Clone for CharacterClass
Sourcefn clone(&self) -> CharacterClass
fn clone(&self) -> CharacterClass
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CharacterClass
impl Debug for CharacterClass
Sourceimpl<'de> Deserialize<'de> for CharacterClass
impl<'de> Deserialize<'de> for CharacterClass
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CharacterClass
impl JsonSchema for CharacterClass
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CharacterClass
impl PartialEq for CharacterClass
Sourceimpl Serialize for CharacterClass
impl Serialize for CharacterClass
Sourceimpl Tsify for CharacterClass
impl Tsify for CharacterClass
const DECL: &'static str = "export interface CharacterClass {\n character_id: CharacterId;\n class_id: ClassId;\n level: number;\n xp: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for CharacterClass
impl StructuralPartialEq for CharacterClass