pub struct Class {Show 19 fields
pub id: ClassId,
pub name: I18nString,
pub description: I18nString,
pub icon_path: String,
pub background_image_path: String,
pub character_asset: String,
pub cast_time: u64,
pub spine: String,
pub basic_abilities: Vec<AbilityId>,
pub class_abilities: Vec<AbilityId>,
pub starter_bundle_id: Option<BundleId>,
pub attributes: Vec<ClassAttribute>,
pub ability_rarity_id: AbilityRarityId,
pub tier: ClassTier,
pub demo_skins: Vec<SkinId>,
pub weapon_type: I18nString,
pub main_attribute: AttributeId,
pub main_attribute_optimal_value: u64,
pub default_weapon_skin_id: SkinId,
}Fields
id: ClassIdname: I18nStringdescription: I18nStringicon_path: Stringbackground_image_path: Stringcharacter_asset: Stringcast_time: u64spine: Stringbasic_abilities: Vec<AbilityId>class_abilities: Vec<AbilityId>starter_bundle_id: Option<BundleId>attributes: Vec<ClassAttribute>ability_rarity_id: AbilityRarityIdtier: ClassTierdemo_skins: Vec<SkinId>weapon_type: I18nStringmain_attribute: AttributeIdmain_attribute_optimal_value: u64default_weapon_skin_id: SkinIdTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Class
impl<'de> Deserialize<'de> for Class
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Class
impl JsonSchema for Class
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for Class
impl Tsify for Class
const DECL: &'static str = "export interface Class {\n id: ClassId;\n name: I18nString;\n description: I18nString;\n icon_path: string;\n background_image_path: string;\n character_asset: string;\n cast_time: number;\n spine: string;\n basic_abilities: AbilityId[];\n class_abilities: AbilityId[];\n starter_bundle_id: BundleId | null;\n attributes: ClassAttribute[];\n ability_rarity_id: AbilityRarityId;\n tier: ClassTier;\n demo_skins: SkinId[];\n weapon_type: I18nString;\n main_attribute: AttributeId;\n main_attribute_optimal_value: number;\n default_weapon_skin_id: SkinId;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for Class
impl StructuralPartialEq for Class