pub struct ClassAbilityLevel {
pub ability_id: AbilityId,
pub level: u64,
}Fields
ability_id: AbilityIdlevel: u64Trait Implementations
Sourceimpl Clone for ClassAbilityLevel
impl Clone for ClassAbilityLevel
Sourcefn clone(&self) -> ClassAbilityLevel
fn clone(&self) -> ClassAbilityLevel
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClassAbilityLevel
impl Debug for ClassAbilityLevel
Sourceimpl Default for ClassAbilityLevel
impl Default for ClassAbilityLevel
Sourcefn default() -> ClassAbilityLevel
fn default() -> ClassAbilityLevel
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ClassAbilityLevel
impl<'de> Deserialize<'de> for ClassAbilityLevel
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ClassAbilityLevel
impl JsonSchema for ClassAbilityLevel
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ClassAbilityLevel
impl PartialEq for ClassAbilityLevel
Sourceimpl Serialize for ClassAbilityLevel
impl Serialize for ClassAbilityLevel
Sourceimpl Tsify for ClassAbilityLevel
impl Tsify for ClassAbilityLevel
const DECL: &'static str = "export interface ClassAbilityLevel {\n ability_id: AbilityId;\n level: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for ClassAbilityLevel
impl StructuralPartialEq for ClassAbilityLevel