pub struct ClassLevels {
pub class_id: ClassId,
pub level: u64,
pub attrs: Vec<EntityAttribute>,
pub price: CurrencyUnit,
pub ability_levels: Vec<ClassAbilityLevel>,
}Fields
class_id: ClassIdlevel: u64attrs: Vec<EntityAttribute>price: CurrencyUnitability_levels: Vec<ClassAbilityLevel>Trait Implementations
Sourceimpl Clone for ClassLevels
impl Clone for ClassLevels
Sourcefn clone(&self) -> ClassLevels
fn clone(&self) -> ClassLevels
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClassLevels
impl Debug for ClassLevels
Sourceimpl Default for ClassLevels
impl Default for ClassLevels
Sourcefn default() -> ClassLevels
fn default() -> ClassLevels
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ClassLevels
impl<'de> Deserialize<'de> for ClassLevels
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ClassLevels
impl JsonSchema for ClassLevels
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ClassLevels
impl PartialEq for ClassLevels
Sourceimpl Serialize for ClassLevels
impl Serialize for ClassLevels
Sourceimpl Tsify for ClassLevels
impl Tsify for ClassLevels
const DECL: &'static str = "export interface ClassLevels {\n class_id: ClassId;\n level: number;\n attrs: EntityAttribute[];\n price: CurrencyUnit;\n ability_levels: ClassAbilityLevel[];\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for ClassLevels
impl StructuralPartialEq for ClassLevels